@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-# Copyright (c) 2010-2014 Sullivan Beck.  All rights reserved.
+# Copyright (c) 2010-2015 Sullivan Beck.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -19,17 +19,18 @@ $Data{'currency'}{'iso'}{'orig'}{'name'} = {
    "US Dollar (Next day) " => "US Dollar (Next day)",
    "US Dollar (Same day) " => "US Dollar (Same day)",
    "Bond Markets Unit European Monetary Unit (E.M.U.-6) "
-                           => "Bond Markets Unit European Monetary Unit (E.M.U.-6)",   "LAND ISLANDS"      => "Aland Islands",
-   "CTE D'IVOIRE"      => "Cote d'Ivoire",
-   "CURAAO"            => "Curacao",
-   "INTERNATIONAL MONETARY FUND (IMF)"
-                           => "International Monetary Fund (IMF)",
+                           => "Bond Markets Unit European Monetary Unit (E.M.U.-6)",
+   "?LAND ISLANDS"      => "Aland Islands",
+   "C?TE D'IVOIRE"      => "Cote d'Ivoire",
+   "CURA?AO"            => "Curacao",
+   "INTERNATIONAL MONETARY FUND (IMF)?"
+                           => "International Monetary Fund (IMF)?",
    "KOREA, DEMOCRATIC PEOPLE’S REPUBLIC OF"
                            => "Korea, Democratic People's Republic of",
    "LAO PEOPLE’S DEMOCRATIC REPUBLIC"
                            => "Lao People's Democratic Republic",
-   "RUNION"            => "Reunion",
-   "SAINT BARTHLEMY"   => "Saint Barthelemy",
+   "R?UNION"            => "Reunion",
+   "SAINT BARTH?LEMY"   => "Saint Barthelemy",
 };
 
 $Data{'currency'}{'iso'}{'ignore'} = {
